@@ -12,8 +12,8 @@ class RoleBinding(NamespacedResource):
 
     def __init__(
         self,
-        name,
-        namespace,
+        name=None,
+        namespace=None,
         client=None,
         subjects_kind=None,
         subjects_name=None,
@@ -22,10 +22,15 @@ class RoleBinding(NamespacedResource):
         role_ref_kind=None,
         role_ref_name=None,
         teardown=True,
+        yaml_file=None,
     ):
 
         super().__init__(
-            name=name, namespace=namespace, client=client, teardown=teardown
+            name=name,
+            namespace=namespace,
+            client=client,
+            teardown=teardown,
+            yaml_file=yaml_file,
         )
         self.subjects_kind = subjects_kind
         self.subjects_name = subjects_name
@@ -36,6 +41,8 @@ class RoleBinding(NamespacedResource):
 
     def to_dict(self):
         res = super().to_dict()
+        if self.yaml_file:
+            return res
 
         subjects = {}
         if self.subjects_kind:
